Builder

Struct Builder 

pub struct Builder { /* private fields */ }
Builder to create a Server instance and modify configuration options

Example

use xvc_server::server::Builder;
use std::time::Duration;

let server = Builder::new()
    .max_vector_size(1024)
    .rw_timeout(Duration::from_secs(20))
    .build(my_server);

Implementations

Source

impl Builder

pub fn new() -> Builder

pub fn max_vector_size(self, size: u32) -> Self

Set the highest vector size that this server is expected to receive.

pub fn rw_timeout(self, timeout: Duration) -> Self

Set the TCP read timeout applied to each message receive.

pub fn build<T: XvcServer>(self, server: T) -> Server<T>

Build and return the server.