pub struct Config {
pub max_vector_size: u32,
pub read_write_timeout: Duration,
}Fields
max_vector_size: u32Maximum JTAG vector size in bytes that the server will accept (default: 10 MiB).
read_write_timeout: DurationTimeout applied to each TCP read. Connections that are idle for longer than this duration are closed (default: 30 s).